ewa.ply.lex.LexerReflect

Package ewa :: Package ply :: Module lex :: Class LexerReflect |
[hide private]
[frames] | no frames]

# Class LexerReflect

source code

    object --+
             |
            LexerReflect

Instance Methods | [hide private]
__init__(self, ldict, log=None, reflags=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_all(self) | source code
validate_all(self) | source code
get_tokens(self) | source code
validate_tokens(self) | source code
get_literals(self) | source code
validate_literals(self) | source code
get_states(self) | source code
get_rules(self) | source code
validate_rules(self) | source code
validate_file(self, filename) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ldict, log=None, reflags=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)